@@ -52,6 +52,7 @@ from ..operations.base import Operations
 from ..util import sqla_compat
 from ..util.sqla_compat import compiles
 
+
 if TYPE_CHECKING:
     from typing import Literal
 
@@ -70,11 +71,11 @@ if TYPE_CHECKING:
     from sqlalchemy.sql.type_api import TypeEngine
 
     from .base import _ServerDefault
+    from .impl import _ReflectedConstraint
     from ..autogenerate.api import AutogenContext
     from ..autogenerate.render import _f_name
     from ..runtime.migration import MigrationContext
 
-
 log = logging.getLogger(__name__)
 
 
@@ -112,6 +113,7 @@ class PostgresqlImpl(DefaultImpl):
         rendered_metadata_default,
         rendered_inspector_default,
     ):
+
         # don't do defaults for SERIAL columns
         if (
             metadata_column.primary_key
@@ -121,6 +123,11 @@ class PostgresqlImpl(DefaultImpl):
 
         conn_col_default = rendered_inspector_default
 
+        if conn_col_default and re.match(
+            r"nextval\('(.+?)'::regclass\)", conn_col_default
+        ):
+            conn_col_default = conn_col_default.replace("::regclass", "")
+
         defaults_equal = conn_col_default == rendered_metadata_default
         if defaults_equal:
             return False
@@ -142,18 +149,23 @@ class PostgresqlImpl(DefaultImpl):
             metadata_default = literal_column(metadata_default)
 
         # run a real compare against the server
+        # TODO: this seems quite a bad idea for a default that's a SQL
+        # function!   SQL functions are not deterministic!
         conn = self.connection
         assert conn is not None
         return not conn.scalar(
             select(literal_column(conn_col_default) == metadata_default)
         )
 
-    def alter_column(  # type:ignore[override]
+    def alter_column(
         self,
         table_name: str,
         column_name: str,
+        *,
         nullable: Optional[bool] = None,
-        server_default: Union[_ServerDefault, Literal[False]] = False,
+        server_default: Optional[
+            Union[_ServerDefault, Literal[False]]
+        ] = False,
         name: Optional[str] = None,
         type_: Optional[TypeEngine] = None,
         schema: Optional[str] = None,
@@ -315,7 +327,7 @@ class PostgresqlImpl(DefaultImpl):
         self, item: Union[Index, UniqueConstraint]
     ) -> Tuple[Any, ...]:
         # only the positive case is returned by sqlalchemy reflection so
-        # None and False are threated the same
+        # None and False are treated the same
         if item.dialect_kwargs.get("postgresql_nulls_not_distinct"):
             return ("nulls_not_distinct",)
         return ()
@@ -409,10 +421,10 @@ class PostgresqlImpl(DefaultImpl):
         return ComparisonResult.Equal()
 
     def adjust_reflected_dialect_options(
-        self, reflected_options: Dict[str, Any], kind: str
+        self, reflected_object: _ReflectedConstraint, kind: str
     ) -> Dict[str, Any]:
         options: Dict[str, Any]
-        options = reflected_options.get("dialect_options", {}).copy()
+        options = reflected_object.get("dialect_options", {}).copy()  # type: ignore[attr-defined]  # noqa: E501
         if not options.get("postgresql_include"):
             options.pop("postgresql_include", None)
         return options
