@@ -441,6 +441,7 @@ class EnvironmentContext(util.ModuleClsProxy):
         sqlalchemy_module_prefix: str = "sa.",
         user_module_prefix: Optional[str] = None,
         on_version_apply: Optional[OnVersionApplyFn] = None,
+        autogenerate_plugins: Sequence[str] | None = None,
         **kw: Any,
     ) -> None:
         """Configure a :class:`.MigrationContext` within this
@@ -860,6 +861,25 @@ class EnvironmentContext(util.ModuleClsProxy):
 
              :paramref:`.command.revision.process_revision_directives`
 
+        :param autogenerate_plugins: A list of string names of "plugins" that
+         should participate in this autogenerate run.   Defaults to the list
+         ``["alembic.autogenerate.*"]``, which indicates that Alembic's default
+         autogeneration plugins will be used.
+
+         See the section :ref:`plugins_autogenerate` for complete background
+         on how to use this parameter.
+
+         .. versionadded:: 1.18.0 Added a new plugin system for autogenerate
+            compare directives.
+
+         .. seealso::
+
+            :ref:`plugins_autogenerate` - background on enabling/disabling
+            autogenerate plugins
+
+            :ref:`alembic.plugins.toplevel` - Introduction and documentation
+            to the plugin system
+
         Parameters specific to individual backends:
 
         :param mssql_batch_separator: The "batch separator" which will
@@ -903,6 +923,9 @@ class EnvironmentContext(util.ModuleClsProxy):
         opts["process_revision_directives"] = process_revision_directives
         opts["on_version_apply"] = util.to_tuple(on_version_apply, default=())
 
+        if autogenerate_plugins is not None:
+            opts["autogenerate_plugins"] = autogenerate_plugins
+
         if render_item is not None:
             opts["render_item"] = render_item
         opts["compare_type"] = compare_type
