@@ -21,7 +21,6 @@ from typing import Tuple
 from typing import TYPE_CHECKING
 from typing import Union
 
-from sqlalchemy import Column
 from sqlalchemy import literal_column
 from sqlalchemy import select
 from sqlalchemy.engine import Engine
@@ -175,7 +174,11 @@ class MigrationContext:
                 opts["output_encoding"],
             )
         else:
-            self.output_buffer = opts.get("output_buffer", sys.stdout)
+            self.output_buffer = opts.get(
+                "output_buffer", sys.stdout
+            )  # type:ignore[assignment]  # noqa: E501
+
+        self.transactional_ddl = transactional_ddl
 
         self._user_compare_type = opts.get("compare_type", True)
         self._user_compare_server_default = opts.get(
@@ -702,54 +705,6 @@ class MigrationContext:
         else:
             return None
 
-    def _compare_type(
-        self, inspector_column: Column[Any], metadata_column: Column
-    ) -> bool:
-        if self._user_compare_type is False:
-            return False
-
-        if callable(self._user_compare_type):
-            user_value = self._user_compare_type(
-                self,
-                inspector_column,
-                metadata_column,
-                inspector_column.type,
-                metadata_column.type,
-            )
-            if user_value is not None:
-                return user_value
-
-        return self.impl.compare_type(inspector_column, metadata_column)
-
-    def _compare_server_default(
-        self,
-        inspector_column: Column[Any],
-        metadata_column: Column[Any],
-        rendered_metadata_default: Optional[str],
-        rendered_column_default: Optional[str],
-    ) -> bool:
-        if self._user_compare_server_default is False:
-            return False
-
-        if callable(self._user_compare_server_default):
-            user_value = self._user_compare_server_default(
-                self,
-                inspector_column,
-                metadata_column,
-                rendered_column_default,
-                metadata_column.server_default,
-                rendered_metadata_default,
-            )
-            if user_value is not None:
-                return user_value
-
-        return self.impl.compare_server_default(
-            inspector_column,
-            metadata_column,
-            rendered_metadata_default,
-            rendered_column_default,
-        )
-
 
 class HeadMaintainer:
     def __init__(self, context: MigrationContext, heads: Any) -> None:
